Union all geometries in a polygonal coverage into a single geometry.
This may be faster than using ST_Union, but may use more memory.
Union all geometries in a polygonal coverage into a single geometry.
This may be faster than using ST_Union, but may use more memory.