Returns the last component of the path similarly to Python's os.path.basename function. If trim_extension is true, the file extension will be removed (defaults to false). separator options: system, both_slash (default), forward_slash, backslash.
Overloads
parse_filename(string = VARCHAR)parse_filename(string = VARCHAR, trim_extension = VARCHAR)parse_filename(string = VARCHAR, trim_extension = BOOLEAN)parse_filename(string = VARCHAR, trim_extension = BOOLEAN, separator = VARCHAR)
See also
Other string:
array_extract(),
ascii(),
bar(),
bin(),
bit_length(),
chr(),
concat(),
concat_ws(),
contains(),
formatReadableDecimalSize(),
format_bytes(),
from_base64(),
greatest(),
hash(),
hex(),
ilike_escape(),
instr(),
least(),
left(),
left_grapheme(),
len(),
length_grapheme(),
like_escape(),
list_slice(),
lower(),
lpad(),
ltrim(),
md5(),
md5_number(),
nfc_normalize(),
not_ilike_escape(),
not_like_escape(),
or–or,
parse_dirname(),
parse_dirpath(),
parse_formatted_bytes(),
parse_path(),
prefix(),
printf(),
repeat(),
replace(),
reverse(),
right(),
right_grapheme(),
rpad(),
rtrim(),
sha1(),
sha256(),
starts_with(),
string_split(),
strip_accents(),
strlen(),
substring(),
substring_grapheme(),
suffix(),
to_base(),
to_base64(),
translate(),
trim(),
unbin(),
unhex(),
unicode(),
upper(),
url_decode(),
url_encode()