regexp_extract(string = VARCHAR, regex = VARCHAR),regexp_extract(string = VARCHAR, regex = VARCHAR, group = INTEGER),regexp_extract(string = VARCHAR, regex = VARCHAR, group = INTEGER, options = VARCHAR): Ifstringcontains theregexpattern, returns the capturing group specified by optional parametergroup; otherwise, returns the empty string. Thegroupmust be a constant value. If nogroupis given, it defaults to 0. A set of optional regexoptionscan be set.regexp_extract(string = VARCHAR, regex = VARCHAR, name_list = `VARCHAR[]`),regexp_extract(string = VARCHAR, regex = VARCHAR, name_list = `VARCHAR[]`, options = VARCHAR): Ifstringcontains theregexpattern, returns the capturing groups as a struct with corresponding names fromname_list; otherwise, returns a struct with the same keys and empty strings as values. A set of optional regexoptionscan be set.
Overloads
regexp_extract(string = VARCHAR, regex = VARCHAR)regexp_extract(string = VARCHAR, regex = VARCHAR, group = INTEGER)regexp_extract(string = VARCHAR, regex = VARCHAR, group = INTEGER, options = VARCHAR)regexp_extract(string = VARCHAR, regex = VARCHAR, name_list = `VARCHAR[]`)regexp_extract(string = VARCHAR, regex = VARCHAR, name_list = `VARCHAR[]`, options = VARCHAR)