Skip to contents

Returns true if string contains the regex, false otherwise. A set of optional regex options can be set.

Usage

regexp_matches(string, regex, options)

Arguments

string, regex, options

VARCHAR

Value

BOOLEAN

Overloads

  • regexp_matches(string = VARCHAR, regex = VARCHAR)

  • regexp_matches(string = VARCHAR, regex = VARCHAR, options = VARCHAR)

SQL examples

regexp_matches('anabanana', '(an)*')