If string contains the regex, replaces the matching part with replacement. A set of optional regex options can be set.
Overloads
regexp_replace(string = VARCHAR, regex = VARCHAR, replacement = VARCHAR)regexp_replace(string = VARCHAR, regex = VARCHAR, replacement = VARCHAR, options = VARCHAR)