Skip to contents

Returns the average of the dependent variable for non-NULL pairs in a group, where x is the independent variable and y is the dependent variable.

Usage

regr_avgy(y, x)

Arguments

y, x

DOUBLE

Value

DOUBLE