Extracts substring starting from grapheme clusters start up to the end of the string. If optional argument length is set, extracts a substring of length grapheme clusters instead. Note that a start value of 1 refers to the first character of the string.
Overloads
substring_grapheme(string = VARCHAR, start = BIGINT, length = BIGINT)substring_grapheme(string = VARCHAR, start = BIGINT)
See also
Other string:
array_extract(),
ascii(),
bar(),
bin(),
bit_length(),
chr(),
concat(),
concat_ws(),
contains(),
formatReadableDecimalSize(),
format_bytes(),
from_base64(),
greatest(),
hash(),
hex(),
ilike_escape(),
instr(),
least(),
left(),
left_grapheme(),
len(),
length_grapheme(),
like_escape(),
list_slice(),
lower(),
lpad(),
ltrim(),
md5(),
md5_number(),
nfc_normalize(),
not_ilike_escape(),
not_like_escape(),
orβor,
parse_dirname(),
parse_dirpath(),
parse_filename(),
parse_formatted_bytes(),
parse_path(),
prefix(),
printf(),
repeat(),
replace(),
reverse(),
right(),
right_grapheme(),
rpad(),
rtrim(),
sha1(),
sha256(),
starts_with(),
string_split(),
strip_accents(),
strlen(),
substring(),
suffix(),
to_base(),
to_base64(),
translate(),
trim(),
unbin(),
unhex(),
unicode(),
upper(),
url_decode(),
url_encode()