Expand the input geometry by the specified distance, returning a polygon.
geom is the input geometry.
distance is the target distance for the expansion, using the same units as the input geometry.
This is a planar operation and will not take into account the curvature of the earth.