R/duckdb-funs.R
ST_LineLocatePoint.Rd
Returns the location on a line closest to a point as a fraction of the total 2D length of the line.
ST_LineLocatePoint(line, point)
GEOMETRY
DOUBLE
The spatial extension (LOAD spatial;).
spatial
LOAD spatial;