ST_MakePoint(x = DOUBLE, y = DOUBLE): Creates a GEOMETRY point from an pair of floating point numbers.For geodetic coordinate systems, x is typically the longitude value and y is the latitude value.
Note that ST_Point is equivalent. ST_MakePoint is provided for PostGIS compatibility.
ST_MakePoint(x = DOUBLE, y = DOUBLE, z = DOUBLE): Creates a POINT_3D.ST_MakePoint(x = DOUBLE, y = DOUBLE, z = DOUBLE, m = DOUBLE): Creates a POINT_4D.