Computes the cosine distance between two arrays of the same size. The array elements can not be NULL. The arrays can have any size as long as the size is the same for both arguments.
Overloads
array_cosine_distance(array1 = `FLOAT[ANY]`, array2 = `FLOAT[ANY]`)array_cosine_distance(array1 = `DOUBLE[ANY]`, array2 = `DOUBLE[ANY]`)