Reduces all elements of the input list into a single scalar value by executing the lambda function on a running result and the next list element. The lambda function has an optional initial_value argument.
Overloads
list_reduce(list = `ANY[]`, `lambda(x,y)` = LAMBDA)list_reduce(list = `ANY[]`, `lambda(x,y)` = LAMBDA, initial_value = ANY)
See also
Other lambda:
list_filter(),
list_transform()
Other list:
array_extract(),
array_length(),
concat(),
contains(),
flatten(),
generate_series(),
len(),
list_aggregate(),
list_concat(),
list_contains(),
list_cosine_distance(),
list_cosine_similarity(),
list_distance(),
list_distinct(),
list_extract(),
list_filter(),
list_grade_up(),
list_has_all(),
list_has_any(),
list_inner_product(),
list_intersect(),
list_negative_inner_product(),
list_position(),
list_resize(),
list_reverse_sort(),
list_select(),
list_slice(),
list_sort(),
list_transform(),
list_unique(),
list_value(),
list_where(),
list_zip(),
or–or,
range(),
repeat(),
unpivot_list()