R/duckdb-funs.R
regexp_full_match.Rd
Returns true if the entire string matches the regex. A set of optional regex options can be set.
true
string
regex
options
VARCHAR
BOOLEAN
regexp_full_match(string = VARCHAR, regex = VARCHAR)
regexp_full_match(string = VARCHAR, regex = VARCHAR, col2 = VARCHAR)
regexp_full_match('anabanana', '(an)*')
Other regex: regexp_escape(), regexp_extract(), regexp_extract_all(), regexp_matches(), regexp_replace(), string_split_regex()
regexp_escape()
regexp_extract()
regexp_extract_all()
regexp_matches()
regexp_replace()
string_split_regex()