R/duckdb-funs.R
regexp_matches.Rd
Returns true if string contains the regex, false otherwise. A set of optional regex options can be set.
true
string
regex
false
options
VARCHAR
BOOLEAN
regexp_matches(string = VARCHAR, regex = VARCHAR)
regexp_matches(string = VARCHAR, regex = VARCHAR, options = VARCHAR)
regexp_matches('anabanana', '(an)*')
Other regex: regexp_escape(), regexp_extract(), regexp_extract_all(), regexp_full_match(), regexp_replace(), string_split_regex()
regexp_escape()
regexp_extract()
regexp_extract_all()
regexp_full_match()
regexp_replace()
string_split_regex()