strptime(text = VARCHAR, format = VARCHAR): Converts thestringtext to timestamp according to the format string. Throws an error on failure. To returnNULLon failure, use try_strptime.strptime(text = VARCHAR, format.list = `VARCHAR[]`): Converts thestringtext to timestamp applying the format strings in the list until one succeeds. Throws an error on failure. To returnNULLon failure, use try_strptime.